pecos.error\_models.noise\_impl.noise\_initz\_bitflip
=====================================================

.. automodule:: pecos.error_models.noise_impl.noise_initz_bitflip







   .. rubric:: Functions

   .. autosummary::

      noise_initz_bitflip
